@@ -69,6 +69,7 @@ $ cat template.yaml | limactl create --name=local -
 		Args:              WrapArgsError(cobra.MaximumNArgs(1)),
 		ValidArgsFunction: createBashComplete,
 		RunE:              createAction,
+		GroupID:           basicCommand,
 	}
 	registerCreateFlags(createCommand, "")
 	return createCommand
@@ -91,6 +92,7 @@ See the examples in 'limactl create --help'.
 		Args:              WrapArgsError(cobra.MaximumNArgs(1)),
 		ValidArgsFunction: startBashComplete,
 		RunE:              startAction,
+		GroupID:           basicCommand,
 	}
 	registerCreateFlags(startCommand, "[limactl create] ")
 	if runtime.GOOS != "windows" {
@@ -146,7 +148,11 @@ func loadOrCreateInstance(cmd *cobra.Command, args []string, createOnly bool) (*
 			}
 		}
 		logrus.Debugf("interpreting argument %q as a http url for instance %q", arg, st.instName)
-		resp, err := http.Get(arg)
+		req, err := http.NewRequestWithContext(cmd.Context(), http.MethodGet, arg, http.NoBody)
+		if err != nil {
+			return nil, err
+		}
+		resp, err := http.DefaultClient.Do(req)
 		if err != nil {
 			return nil, err
 		}
