@@ -5,7 +5,6 @@ import (
 	"fmt"
 	"time"
 
-	guestagentclient "github.com/lima-vm/lima/pkg/guestagent/api/client"
 	"github.com/lima-vm/lima/pkg/limayaml"
 	"github.com/lima-vm/sshocker/pkg/ssh"
 	"github.com/sirupsen/logrus"
@@ -119,41 +118,6 @@ fi
 `,
 			debugHint: `Append "user_allow_other" to /etc/fuse.conf (/etc/fuse3.conf) in the guest`,
 		})
-
-	}
-	if a.guestAgentProto == guestagentclient.VSOCK {
-		req = append(req, requirement{
-			description: "the guest agent to be running",
-			script: fmt.Sprintf(`#!/bin/bash
-set -eux -o pipefail
-if ! timeout 30s bash -c "until ss -a -n --vsock --listen | grep -q '*:%d'; do sleep 3; done"; then
-	echo >&2 "lima-guestagent is not installed yet"
-	exit 1
-fi
-`, a.vSockPort),
-			debugHint: `The guest agent (/run/lima-guestagent.sock) does not seem running.
-Make sure that you are using an officially supported image.
-Also see "/var/log/cloud-init-output.log" in the guest.
-A possible workaround is to run "lima-guestagent install-systemd" in the guest.
-`,
-		})
-	} else {
-		req = append(req, requirement{
-			description: "the guest agent to be running",
-			script: `#!/bin/bash
-set -eux -o pipefail
-sock="/run/lima-guestagent.sock"
-if ! timeout 30s bash -c "until [ -S \"${sock}\" ]; do sleep 3; done"; then
-	echo >&2 "lima-guestagent is not installed yet"
-	exit 1
-fi
-`,
-			debugHint: `The guest agent (/run/lima-guestagent.sock) does not seem running.
-Make sure that you are using an officially supported image.
-Also see "/var/log/cloud-init-output.log" in the guest.
-A possible workaround is to run "lima-guestagent install-systemd" in the guest.
-`,
-		})
 	}
 	return req
 }
