@@ -73,6 +73,7 @@ func TestFillDefault(t *testing.T) {
 		Memory:             ptr.Of(defaultMemoryAsString()),
 		Disk:               ptr.Of(defaultDiskSizeAsString()),
 		GuestInstallPrefix: ptr.Of(defaultGuestInstallPrefix()),
+		UpgradePackages:    ptr.Of(false),
 		Containerd: Containerd{
 			System:   ptr.Of(false),
 			User:     ptr.Of(true),
@@ -85,6 +86,7 @@ func TestFillDefault(t *testing.T) {
 			ForwardX11:        ptr.Of(false),
 			ForwardX11Trusted: ptr.Of(false),
 		},
+		TimeZone: ptr.Of(hostTimeZone()),
 		Firmware: Firmware{
 			LegacyBIOS: ptr.Of(false),
 		},
@@ -181,6 +183,7 @@ func TestFillDefault(t *testing.T) {
 				"-----BEGIN CERTIFICATE-----\nYOUR-ORGS-TRUSTED-CA-CERT\n-----END CERTIFICATE-----\n",
 			},
 		},
+		TimeZone: ptr.Of("Antarctica/Troll"),
 		Firmware: Firmware{
 			LegacyBIOS: ptr.Of(false),
 			Images: []FileWithVMType{
@@ -273,6 +276,7 @@ func TestFillDefault(t *testing.T) {
 		},
 	}
 
+	expect.TimeZone = y.TimeZone
 	expect.Firmware = y.Firmware
 
 	expect.Rosetta = Rosetta{
@@ -306,6 +310,7 @@ func TestFillDefault(t *testing.T) {
 			{Name: "data"},
 		},
 		GuestInstallPrefix: ptr.Of("/opt"),
+		UpgradePackages:    ptr.Of(true),
 		Containerd: Containerd{
 			System: ptr.Of(true),
 			User:   ptr.Of(false),
@@ -320,6 +325,7 @@ func TestFillDefault(t *testing.T) {
 			ForwardX11:        ptr.Of(false),
 			ForwardX11Trusted: ptr.Of(false),
 		},
+		TimeZone: ptr.Of("Zulu"),
 		Firmware: Firmware{
 			LegacyBIOS: ptr.Of(true),
 			Images: []FileWithVMType{
@@ -494,6 +500,7 @@ func TestFillDefault(t *testing.T) {
 			{Name: "test"},
 		},
 		GuestInstallPrefix: ptr.Of("/usr"),
+		UpgradePackages:    ptr.Of(true),
 		Containerd: Containerd{
 			System: ptr.Of(true),
 			User:   ptr.Of(false),
@@ -512,6 +519,7 @@ func TestFillDefault(t *testing.T) {
 			ForwardX11:        ptr.Of(false),
 			ForwardX11Trusted: ptr.Of(false),
 		},
+		TimeZone: ptr.Of("Universal"),
 		Firmware: Firmware{
 			LegacyBIOS: ptr.Of(true),
 		},
