@@ -1,5 +1,4 @@
 //go:build !linux && !windows
-// +build !linux,!windows
 
 package osutil
 
@@ -13,8 +12,8 @@ const UnixPathMax = 104
 
 // Stat is a selection of syscall.Stat_t
 type Stat struct {
-	Uid uint32 //nolint:revive
-	Gid uint32 //nolint:revive
+	Uid uint32
+	Gid uint32
 }
 
 func SysStat(fi fs.FileInfo) (Stat, bool) {
